==> DateTime-Locale-1.28.tar.gz: DateTime-Locale-1.28/share/os-RU.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd.MM",
    MMM => "LLL",
    MMMEd => "ccc, d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "dd.MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM.y",
    yMEd => "E, dd.MM.y",
    yMMM => "LLL y",
    yMMMEd => "E, d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y-'\N{U+04d5}\N{U+043c}' '\N{U+0430}\N{U+0437}\N{U+044b}' QQQ",
    yQQQQ => "y-'\N{U+04d5}\N{U+043c}' '\N{U+0430}\N{U+0437}\N{U+044b}' QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "os-RU",
  date_format_full => "EEEE, d MMMM, y '\N{U+0430}\N{U+0437}'",
  date_format_long => "d MMMM, y '\N{U+0430}\N{U+0437}'",
  date_format_medium => "dd MMM y '\N{U+0430}\N{U+0437}'",
  date_format_short => "dd.MM.yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+043a}\N{U+0440}\N{U+0441}",
    "\N{U+0434}\N{U+0446}\N{U+0433}",
    "\N{U+04d5}\N{U+0440}\N{U+0442}",
    "\N{U+0446}\N{U+043f}\N{U+0440}",
    "\N{U+043c}\N{U+0440}\N{U+0431}",
    "\N{U+0441}\N{U+0431}\N{U+0442}",
    "\N{U+0445}\N{U+0446}\N{U+0431}",
  ],
  day_format_narrow => [
    "\N{U+041a}",
    "\N{U+0414}",
    "\N{U+04d4}",
    "\N{U+0426}",
    "\N{U+041c}",
    "\N{U+0421}",
    "\N{U+0425}",
  ],
  day_format_wide => [
    "\N{U+043a}\N{U+044a}\N{U+0443}\N{U+044b}\N{U+0440}\N{U+0438}\N{U+0441}\N{U+04d5}\N{U+0440}",
    "\N{U+0434}\N{U+044b}\N{U+0446}\N{U+0446}\N{U+04d5}\N{U+0433}",
    "\N{U+04d5}\N{U+0440}\N{U+0442}\N{U+044b}\N{U+0446}\N{U+0446}\N{U+04d5}\N{U+0433}",
    "\N{U+0446}\N{U+044b}\N{U+043f}\N{U+043f}\N{U+04d5}\N{U+0440}\N{U+04d5}\N{U+043c}",
    "\N{U+043c}\N{U+0430}\N{U+0439}\N{U+0440}\N{U+04d5}\N{U+043c}\N{U+0431}\N{U+043e}\N{U+043d}",
    "\N{U+0441}\N{U+0430}\N{U+0431}\N{U+0430}\N{U+0442}",
    "\N{U+0445}\N{U+0443}\N{U+044b}\N{U+0446}\N{U+0430}\N{U+0443}\N{U+0431}\N{U+043e}\N{U+043d}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+041a}\N{U+0440}\N{U+0441}",
    "\N{U+0414}\N{U+0446}\N{U+0433}",
    "\N{U+04d4}\N{U+0440}\N{U+0442}",
    "\N{U+0426}\N{U+043f}\N{U+0440}",
    "\N{U+041c}\N{U+0440}\N{U+0431}",
    "\N{U+0421}\N{U+0431}\N{U+0442}",
    "\N{U+0425}\N{U+0446}\N{U+0431}",
  ],
  day_stand_alone_narrow => [
    "\N{U+041a}",
    "\N{U+0414}",
    "\N{U+04d4}",
    "\N{U+0426}",
    "\N{U+041c}",
    "\N{U+0421}",
    "\N{U+0425}",
  ],
  day_stand_alone_wide => [
    "\N{U+041a}\N{U+044a}\N{U+0443}\N{U+044b}\N{U+0440}\N{U+0438}\N{U+0441}\N{U+04d5}\N{U+0440}",
    "\N{U+0414}\N{U+044b}\N{U+0446}\N{U+0446}\N{U+04d5}\N{U+0433}",
    "\N{U+04d4}\N{U+0440}\N{U+0442}\N{U+044b}\N{U+0446}\N{U+0446}\N{U+04d5}\N{U+0433}",
    "\N{U+0426}\N{U+044b}\N{U+043f}\N{U+043f}\N{U+04d5}\N{U+0440}\N{U+04d5}\N{U+043c}",
    "\N{U+041c}\N{U+0430}\N{U+0439}\N{U+0440}\N{U+04d5}\N{U+043c}\N{U+0431}\N{U+043e}\N{U+043d}",
    "\N{U+0421}\N{U+0430}\N{U+0431}\N{U+0430}\N{U+0442}",
    "\N{U+0425}\N{U+0443}\N{U+044b}\N{U+0446}\N{U+0430}\N{U+0443}\N{U+0431}\N{U+043e}\N{U+043d}",
  ],
  era_abbreviated => [
    "\N{U+043d}.\N{U+0434}.\N{U+0430}.",
    "\N{U+043d}.\N{U+0434}.",
  ],
  era_narrow => [
    "\N{U+043d}.\N{U+0434}.\N{U+0430}.",
    "\N{U+043d}.\N{U+0434}.",
  ],
  era_wide => [
    "\N{U+043d}.\N{U+0434}.\N{U+0430}.",
    "\N{U+043d}.\N{U+0434}.",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%d.%m.%Y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Ossetic",
  month_format_abbreviated => [
    "\N{U+044f}\N{U+043d}\N{U+0432}.",
    "\N{U+0444}\N{U+0435}\N{U+0432}.",
    "\N{U+043c}\N{U+0430}\N{U+0440}.",
    "\N{U+0430}\N{U+043f}\N{U+0440}.",
    "\N{U+043c}\N{U+0430}\N{U+0439}\N{U+044b}",
    "\N{U+0438}\N{U+044e}\N{U+043d}\N{U+044b}",
    "\N{U+0438}\N{U+044e}\N{U+043b}\N{U+044b}",
    "\N{U+0430}\N{U+0432}\N{U+0433}.",
    "\N{U+0441}\N{U+0435}\N{U+043d}.",
    "\N{U+043e}\N{U+043a}\N{U+0442}.",
    "\N{U+043d}\N{U+043e}\N{U+044f}.",
    "\N{U+0434}\N{U+0435}\N{U+043a}.",
  ],
  month_format_narrow => [
    "\N{U+042f}",
    "\N{U+0424}",
    "\N{U+041c}",
    "\N{U+0410}",
    "\N{U+041c}",
    "\N{U+0418}",
    "\N{U+0418}",
    "\N{U+0410}",
    "\N{U+0421}",
    "\N{U+041e}",
    "\N{U+041d}",
    "\N{U+0414}",
  ],
  month_format_wide => [
    "\N{U+044f}\N{U+043d}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+044b}",
    "\N{U+0444}\N{U+0435}\N{U+0432}\N{U+0440}\N{U+0430}\N{U+043b}\N{U+044b}",
    "\N{U+043c}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+044a}\N{U+0438}\N{U+0439}\N{U+044b}",
    "\N{U+0430}\N{U+043f}\N{U+0440}\N{U+0435}\N{U+043b}\N{U+044b}",
    "\N{U+043c}\N{U+0430}\N{U+0439}\N{U+044b}",
    "\N{U+0438}\N{U+044e}\N{U+043d}\N{U+044b}",
    "\N{U+0438}\N{U+044e}\N{U+043b}\N{U+044b}",
    "\N{U+0430}\N{U+0432}\N{U+0433}\N{U+0443}\N{U+0441}\N{U+0442}\N{U+044b}",
    "\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}\N{U+044b}",
    "\N{U+043e}\N{U+043a}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}\N{U+044b}",
    "\N{U+043d}\N{U+043e}\N{U+044f}\N{U+0431}\N{U+0440}\N{U+044b}",
    "\N{U+0434}\N{U+0435}\N{U+043a}\N{U+0430}\N{U+0431}\N{U+0440}\N{U+044b}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+042f}\N{U+043d}\N{U+0432}.",
    "\N{U+0424}\N{U+0435}\N{U+0432}\N{U+0440}.",
    "\N{U+041c}\N{U+0430}\N{U+0440}\N{U+0442}.",
    "\N{U+0410}\N{U+043f}\N{U+0440}.",
    "\N{U+041c}\N{U+0430}\N{U+0439}",
    "\N{U+0418}\N{U+044e}\N{U+043d}\N{U+044c}",
    "\N{U+0418}\N{U+044e}\N{U+043b}\N{U+044c}",
    "\N{U+0410}\N{U+0432}\N{U+0433}.",
    "\N{U+0421}\N{U+0435}\N{U+043d}\N{U+0442}.",
    "\N{U+041e}\N{U+043a}\N{U+0442}.",
    "\N{U+041d}\N{U+043e}\N{U+044f}\N{U+0431}.",
    "\N{U+0414}\N{U+0435}\N{U+043a}.",
  ],
  month_stand_alone_narrow => [
    "\N{U+042f}",
    "\N{U+0424}",
    "\N{U+041c}",
    "\N{U+0410}",
    "\N{U+041c}",
    "\N{U+0418}",
    "\N{U+0418}",
    "\N{U+0410}",
    "\N{U+0421}",
    "\N{U+041e}",
    "\N{U+041d}",
    "\N{U+0414}",
  ],
  month_stand_alone_wide => [
    "\N{U+042f}\N{U+043d}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+044c}",
    "\N{U+0424}\N{U+0435}\N{U+0432}\N{U+0440}\N{U+0430}\N{U+043b}\N{U+044c}",
    "\N{U+041c}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+044a}\N{U+0438}",
    "\N{U+0410}\N{U+043f}\N{U+0440}\N{U+0435}\N{U+043b}\N{U+044c}",
    "\N{U+041c}\N{U+0430}\N{U+0439}",
    "\N{U+0418}\N{U+044e}\N{U+043d}\N{U+044c}",
    "\N{U+0418}\N{U+044e}\N{U+043b}\N{U+044c}",
    "\N{U+0410}\N{U+0432}\N{U+0433}\N{U+0443}\N{U+0441}\N{U+0442}",
    "\N{U+0421}\N{U+0435}\N{U+043d}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}\N{U+044c}",
    "\N{U+041e}\N{U+043a}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}\N{U+044c}",
    "\N{U+041d}\N{U+043e}\N{U+044f}\N{U+0431}\N{U+0440}\N{U+044c}",
    "\N{U+0414}\N{U+0435}\N{U+043a}\N{U+0430}\N{U+0431}\N{U+0440}\N{U+044c}",
  ],
  name => "Ossetic Russia",
  native_language => "\N{U+0438}\N{U+0440}\N{U+043e}\N{U+043d}",
  native_name => "\N{U+0438}\N{U+0440}\N{U+043e}\N{U+043d} \N{U+0423}\N{U+04d5}\N{U+0440}\N{U+04d5}\N{U+0441}\N{U+0435}",
  native_script => undef,
  native_territory => "\N{U+0423}\N{U+04d5}\N{U+0440}\N{U+04d5}\N{U+0441}\N{U+0435}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}.",
    "2-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}.",
    "3-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}.",
    "4-\N{U+04d5}\N{U+043c} \N{U+043a}\N{U+0432}.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "2-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "3-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "4-\N{U+04d5}\N{U+043c} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
  ],
  quarter_stand_alone_abbreviated => [
    "1-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}.",
    "2-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}.",
    "3-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}.",
    "4-\N{U+04d5}\N{U+043c} \N{U+043a}\N{U+0432}.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "2-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "3-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "4-\N{U+04d5}\N{U+043c} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
  ],
  script => undef,
  territory => "Russia",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 37,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/os-RU.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd.MM",
    MMM => "LLL",
    MMMEd => "ccc, d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "dd.MM",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM.y",
    yMEd => "E, dd.MM.y",
    yMMM => "LLL y",
    yMMMEd => "E, d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y-'\N{U+04d5}\N{U+043c}' '\N{U+0430}\N{U+0437}\N{U+044b}' QQQ",
    yQQQQ => "y-'\N{U+04d5}\N{U+043c}' '\N{U+0430}\N{U+0437}\N{U+044b}' QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "os-RU",
  date_format_full => "EEEE, d MMMM, y\N{U+202f}'\N{U+0430}\N{U+0437}'",
  date_format_long => "d MMMM, y\N{U+202f}'\N{U+0430}\N{U+0437}'",
  date_format_medium => "dd MMM y\N{U+202f}'\N{U+0430}\N{U+0437}'",
  date_format_short => "dd.MM.yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+043a}\N{U+0440}\N{U+0441}",
    "\N{U+0434}\N{U+0446}\N{U+0433}",
    "\N{U+04d5}\N{U+0440}\N{U+0442}",
    "\N{U+0446}\N{U+043f}\N{U+0440}",
    "\N{U+043c}\N{U+0440}\N{U+0431}",
    "\N{U+0441}\N{U+0431}\N{U+0442}",
    "\N{U+0445}\N{U+0446}\N{U+0431}",
  ],
  day_format_narrow => [
    "\N{U+041a}",
    "\N{U+0414}",
    "\N{U+04d4}",
    "\N{U+0426}",
    "\N{U+041c}",
    "\N{U+0421}",
    "\N{U+0425}",
  ],
  day_format_wide => [
    "\N{U+043a}\N{U+044a}\N{U+0443}\N{U+044b}\N{U+0440}\N{U+0438}\N{U+0441}\N{U+04d5}\N{U+0440}",
    "\N{U+0434}\N{U+044b}\N{U+0446}\N{U+0446}\N{U+04d5}\N{U+0433}",
    "\N{U+04d5}\N{U+0440}\N{U+0442}\N{U+044b}\N{U+0446}\N{U+0446}\N{U+04d5}\N{U+0433}",
    "\N{U+0446}\N{U+044b}\N{U+043f}\N{U+043f}\N{U+04d5}\N{U+0440}\N{U+04d5}\N{U+043c}",
    "\N{U+043c}\N{U+0430}\N{U+0439}\N{U+0440}\N{U+04d5}\N{U+043c}\N{U+0431}\N{U+043e}\N{U+043d}",
    "\N{U+0441}\N{U+0430}\N{U+0431}\N{U+0430}\N{U+0442}",
    "\N{U+0445}\N{U+0443}\N{U+044b}\N{U+0446}\N{U+0430}\N{U+0443}\N{U+0431}\N{U+043e}\N{U+043d}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+041a}\N{U+0440}\N{U+0441}",
    "\N{U+0414}\N{U+0446}\N{U+0433}",
    "\N{U+04d4}\N{U+0440}\N{U+0442}",
    "\N{U+0426}\N{U+043f}\N{U+0440}",
    "\N{U+041c}\N{U+0440}\N{U+0431}",
    "\N{U+0421}\N{U+0431}\N{U+0442}",
    "\N{U+0425}\N{U+0446}\N{U+0431}",
  ],
  day_stand_alone_narrow => [
    "\N{U+041a}",
    "\N{U+0414}",
    "\N{U+04d4}",
    "\N{U+0426}",
    "\N{U+041c}",
    "\N{U+0421}",
    "\N{U+0425}",
  ],
  day_stand_alone_wide => [
    "\N{U+041a}\N{U+044a}\N{U+0443}\N{U+044b}\N{U+0440}\N{U+0438}\N{U+0441}\N{U+04d5}\N{U+0440}",
    "\N{U+0414}\N{U+044b}\N{U+0446}\N{U+0446}\N{U+04d5}\N{U+0433}",
    "\N{U+04d4}\N{U+0440}\N{U+0442}\N{U+044b}\N{U+0446}\N{U+0446}\N{U+04d5}\N{U+0433}",
    "\N{U+0426}\N{U+044b}\N{U+043f}\N{U+043f}\N{U+04d5}\N{U+0440}\N{U+04d5}\N{U+043c}",
    "\N{U+041c}\N{U+0430}\N{U+0439}\N{U+0440}\N{U+04d5}\N{U+043c}\N{U+0431}\N{U+043e}\N{U+043d}",
    "\N{U+0421}\N{U+0430}\N{U+0431}\N{U+0430}\N{U+0442}",
    "\N{U+0425}\N{U+0443}\N{U+044b}\N{U+0446}\N{U+0430}\N{U+0443}\N{U+0431}\N{U+043e}\N{U+043d}",
  ],
  era_abbreviated => [
    "\N{U+043d}.\N{U+0434}.\N{U+0430}.",
    "\N{U+043d}.\N{U+0434}.",
  ],
  era_narrow => [
    "\N{U+043d}.\N{U+0434}.\N{U+0430}.",
    "\N{U+043d}.\N{U+0434}.",
  ],
  era_wide => [
    "\N{U+043d}.\N{U+0434}.\N{U+0430}.",
    "\N{U+043d}.\N{U+0434}.",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d.%m.%Y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Ossetic",
  month_format_abbreviated => [
    "\N{U+044f}\N{U+043d}\N{U+0432}.",
    "\N{U+0444}\N{U+0435}\N{U+0432}.",
    "\N{U+043c}\N{U+0430}\N{U+0440}.",
    "\N{U+0430}\N{U+043f}\N{U+0440}.",
    "\N{U+043c}\N{U+0430}\N{U+0439}\N{U+044b}",
    "\N{U+0438}\N{U+044e}\N{U+043d}\N{U+044b}",
    "\N{U+0438}\N{U+044e}\N{U+043b}\N{U+044b}",
    "\N{U+0430}\N{U+0432}\N{U+0433}.",
    "\N{U+0441}\N{U+0435}\N{U+043d}.",
    "\N{U+043e}\N{U+043a}\N{U+0442}.",
    "\N{U+043d}\N{U+043e}\N{U+044f}.",
    "\N{U+0434}\N{U+0435}\N{U+043a}.",
  ],
  month_format_narrow => [
    "\N{U+042f}",
    "\N{U+0424}",
    "\N{U+041c}",
    "\N{U+0410}",
    "\N{U+041c}",
    "\N{U+0418}",
    "\N{U+0418}",
    "\N{U+0410}",
    "\N{U+0421}",
    "\N{U+041e}",
    "\N{U+041d}",
    "\N{U+0414}",
  ],
  month_format_wide => [
    "\N{U+044f}\N{U+043d}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+044b}",
    "\N{U+0444}\N{U+0435}\N{U+0432}\N{U+0440}\N{U+0430}\N{U+043b}\N{U+044b}",
    "\N{U+043c}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+044a}\N{U+0438}\N{U+0439}\N{U+044b}",
    "\N{U+0430}\N{U+043f}\N{U+0440}\N{U+0435}\N{U+043b}\N{U+044b}",
    "\N{U+043c}\N{U+0430}\N{U+0439}\N{U+044b}",
    "\N{U+0438}\N{U+044e}\N{U+043d}\N{U+044b}",
    "\N{U+0438}\N{U+044e}\N{U+043b}\N{U+044b}",
    "\N{U+0430}\N{U+0432}\N{U+0433}\N{U+0443}\N{U+0441}\N{U+0442}\N{U+044b}",
    "\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}\N{U+044b}",
    "\N{U+043e}\N{U+043a}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}\N{U+044b}",
    "\N{U+043d}\N{U+043e}\N{U+044f}\N{U+0431}\N{U+0440}\N{U+044b}",
    "\N{U+0434}\N{U+0435}\N{U+043a}\N{U+0430}\N{U+0431}\N{U+0440}\N{U+044b}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+042f}\N{U+043d}\N{U+0432}.",
    "\N{U+0424}\N{U+0435}\N{U+0432}\N{U+0440}.",
    "\N{U+041c}\N{U+0430}\N{U+0440}\N{U+0442}.",
    "\N{U+0410}\N{U+043f}\N{U+0440}.",
    "\N{U+041c}\N{U+0430}\N{U+0439}",
    "\N{U+0418}\N{U+044e}\N{U+043d}\N{U+044c}",
    "\N{U+0418}\N{U+044e}\N{U+043b}\N{U+044c}",
    "\N{U+0410}\N{U+0432}\N{U+0433}.",
    "\N{U+0421}\N{U+0435}\N{U+043d}\N{U+0442}.",
    "\N{U+041e}\N{U+043a}\N{U+0442}.",
    "\N{U+041d}\N{U+043e}\N{U+044f}\N{U+0431}.",
    "\N{U+0414}\N{U+0435}\N{U+043a}.",
  ],
  month_stand_alone_narrow => [
    "\N{U+042f}",
    "\N{U+0424}",
    "\N{U+041c}",
    "\N{U+0410}",
    "\N{U+041c}",
    "\N{U+0418}",
    "\N{U+0418}",
    "\N{U+0410}",
    "\N{U+0421}",
    "\N{U+041e}",
    "\N{U+041d}",
    "\N{U+0414}",
  ],
  month_stand_alone_wide => [
    "\N{U+042f}\N{U+043d}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+044c}",
    "\N{U+0424}\N{U+0435}\N{U+0432}\N{U+0440}\N{U+0430}\N{U+043b}\N{U+044c}",
    "\N{U+041c}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+044a}\N{U+0438}",
    "\N{U+0410}\N{U+043f}\N{U+0440}\N{U+0435}\N{U+043b}\N{U+044c}",
    "\N{U+041c}\N{U+0430}\N{U+0439}",
    "\N{U+0418}\N{U+044e}\N{U+043d}\N{U+044c}",
    "\N{U+0418}\N{U+044e}\N{U+043b}\N{U+044c}",
    "\N{U+0410}\N{U+0432}\N{U+0433}\N{U+0443}\N{U+0441}\N{U+0442}",
    "\N{U+0421}\N{U+0435}\N{U+043d}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}\N{U+044c}",
    "\N{U+041e}\N{U+043a}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}\N{U+044c}",
    "\N{U+041d}\N{U+043e}\N{U+044f}\N{U+0431}\N{U+0440}\N{U+044c}",
    "\N{U+0414}\N{U+0435}\N{U+043a}\N{U+0430}\N{U+0431}\N{U+0440}\N{U+044c}",
  ],
  name => "Ossetic Russia",
  native_language => "\N{U+0438}\N{U+0440}\N{U+043e}\N{U+043d}",
  native_name => "\N{U+0438}\N{U+0440}\N{U+043e}\N{U+043d} \N{U+0423}\N{U+04d5}\N{U+0440}\N{U+04d5}\N{U+0441}\N{U+0435}",
  native_script => undef,
  native_territory => "\N{U+0423}\N{U+04d5}\N{U+0440}\N{U+04d5}\N{U+0441}\N{U+0435}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}.",
    "2-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}.",
    "3-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}.",
    "4-\N{U+04d5}\N{U+043c} \N{U+043a}\N{U+0432}.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "2-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "3-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "4-\N{U+04d5}\N{U+043c} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
  ],
  quarter_stand_alone_abbreviated => [
    "1-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}.",
    "2-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}.",
    "3-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}.",
    "4-\N{U+04d5}\N{U+043c} \N{U+043a}\N{U+0432}.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "2-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "3-\N{U+0430}\N{U+0433} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "4-\N{U+04d5}\N{U+043c} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
  ],
  script => undef,
  territory => "Russia",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => "44.1",
}
